==> scummvm_2.1.1+dfsg1.orig.tar.xz: scummvm-2.1.1/devtools/create_kyradat/resources/lok_dos_cd_english.h <==
static const char *const k1IntroStringsDOSCDEnglish[51] = {
	"This is a text test - 1",
	"This is a text test - 2",
	"Greetings, Kallak...",
	"...Powerful leader of the Royal Mystics!",
	"Did I frighten you?",
	"Malcolm!",
	"I heard yesterday of your escape.",
	"And have expected you before now.",
	"Why would I rush?",
	"I rule this land!",
	"Your puny curse restrains me naught.",
	"So, slay me now!",
	"I have little magic left.",
	"I mean to harm you, have no doubt...",
	"...Now you are stone...",
	"...Yet I leave your eyes.",
	"I shed no tears for Kyrandia...",
	"...But cannot deny you yours.",
	"Malcolm the Jester has broken free!",
	"He now controls the Kyragem...",
	"...source of all magic in Kyrandia!",
	"",
	"How dare you trip ME!",
	"But no, something special for you...",
	"A humorous hex!",
	"But I shall give fair warning.",
	"Don't jump on THAT tree!",
	"Don't climb up THAT tree little squirrel!",
	"Boo!",
	"Tis funnier that way...",
	"...Is it not?",
	"Ha ha ha...",
	"Aren't fingers wonderful?",
	"It's great to be alive!",
	"Brandon!",
	"Grandfather! We did it!",
	"No! YOU did it!",
	"Long live King Brandon!",
	"Long live the Royal Mystics!",
	"Now, let's go put Kyrandia back together!",
	"Good idea!",
	"As my first Royal Proclamation...",
	"I name sandals as the official footwear of Kyrandia!",
	"Well done, Brandon!",
	"The Land no longer weeps...",
	"And your friends have been restored!",
	"Dear Brynn...",
	"Malcolm has broken free!",
	"Soon he will come for me.",
	"Please help Brandon...",
	""
};

static const StringListProvider k1IntroStringsDOSCDEnglishProvider = { ARRAYSIZE(k1IntroStringsDOSCDEnglish), k1IntroStringsDOSCDEnglish };

static const char *const k1ItemNamesDOSCDEnglish[107] = {
	"Garnet",
	"Amethyst",
	"Aquamarine",
	"Diamond",
	"Emerald",
	"Pearl",
	"Ruby",
	"Peridot",
	"Sapphire",
	"Opal",
	"Topaz",
	"Onyx",
	"Sunstone",
	"Moonstone",
	"Rainbowstone",
	"Lodestone",
	"Rose",
	"Tulip",
	"Orchid",
	"Silver Rose",
	"Silver Statuette",
	"Silver Coin",
	"Gold Coin",
	"Gold Ring",
	"Royal Chalice",
	"Pinecone",
	"Acorn",
	"Walnut",
	"Everglowing Fireberries",
	"Fireberries",
	"Fireberries",
	"Fireberries",
	"Fireberries",
	"Fireberries",
	"Fish",
	"Fish Bone",
	"Mutton Leg",
	"Bone",
	"Apple",
	"Apple Core",
	"Blueberries",
	"Mushroom",
	"Note",
	"Marble",
	"Saw",
	"Ankh",
	"Feather",
	"Egg",
	"Leaf",
	"Shamrock",
	"Fallen Star",
	"Crystal Ball",
	"Teardrop",
	"Mirror",
	"Ice Shard",
	"Flute",
	"Hourglass",
	"Iron Key",
	"Jade Key",
	"Obsidion Key",
	"Red Potion",
	"Red Potion",
	"Blue Potion",
	"Blue Potion",
	"Yellow Potion",
	"Yellow Potion",
	"Green Potion",
	"Orange Potion",
	"Purple Potion",
	"Potion of Rainbows",
	"Fresh Water",
	"Fresh Water",
	"Salt Water",
	"Salt Water",
	"Mineral Water",
	"Mineral Water",
	"Magical Water",
	"Magical Water",
	"Empty Flask",
	"Empty Flask",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Parchment scrap",
	"Parchment scrap",
	"Parchment scrap",
	"Parchment scrap",
	"Parchment scrap",
	"Red Magestone",
	"Orange Magestone",
	"Yellow Magestone",
	"Green Magestone",
	"Blue-Green Magestone",
	"Blue Magestone",
	"Purple Magestone",
	"Heavy rock",
	"Royal Crown",
	"Royal Sceptre",
	"Gold key",
	"Unknown item"
};

static const StringListProvider k1ItemNamesDOSCDEnglishProvider = { ARRAYSIZE(k1ItemNamesDOSCDEnglish), k1ItemNamesDOSCDEnglish };

static const char *const k1TakenStringsDOSCDEnglish[2] = {
	" taken.",
	" taken."
};

static const StringListProvider k1TakenStringsDOSCDEnglishProvider = { ARRAYSIZE(k1TakenStringsDOSCDEnglish), k1TakenStringsDOSCDEnglish };

static const char *const k1PlacedStringsDOSCDEnglish[1] = {
	" placed."
};

static const StringListProvider k1PlacedStringsDOSCDEnglishProvider = { ARRAYSIZE(k1PlacedStringsDOSCDEnglish), k1PlacedStringsDOSCDEnglish };

static const char *const k1DroppedStringsDOSCDEnglish[1] = {
	" dropped."
};

static const StringListProvider k1DroppedStringsDOSCDEnglishProvider = { ARRAYSIZE(k1DroppedStringsDOSCDEnglish), k1DroppedStringsDOSCDEnglish };

static const char *const k1NoDropStringsDOSCDEnglish[2] = {
	"You can't drop any more items in this scene.",
	"You can't put that there."
};

static const StringListProvider k1NoDropStringsDOSCDEnglishProvider = { ARRAYSIZE(k1NoDropStringsDOSCDEnglish), k1NoDropStringsDOSCDEnglish };

static const char *const k1PutDownStringDOSCDEnglish[1] = {
	"Maybe I'd better put this down first."
};

static const StringListProvider k1PutDownStringDOSCDEnglishProvider = { ARRAYSIZE(k1PutDownStringDOSCDEnglish), k1PutDownStringDOSCDEnglish };

static const char *const k1WaitAmuletStringDOSCDEnglish[1] = {
	"I guess I'll have to wait for my Amulet to regain its power."
};

static const StringListProvider k1WaitAmuletStringDOSCDEnglishProvider = { ARRAYSIZE(k1WaitAmuletStringDOSCDEnglish), k1WaitAmuletStringDOSCDEnglish };

static const char *const k1BlackJewelStringDOSCDEnglish[1] = {
	"It's a jewel, but why is it black?"
};

static const StringListProvider k1BlackJewelStringDOSCDEnglishProvider = { ARRAYSIZE(k1BlackJewelStringDOSCDEnglish), k1BlackJewelStringDOSCDEnglish };

static const char *const k1HealingTipStringDOSCDEnglish[1] = {
	"Gee, this could come in handy if I get hurt."
};

static const StringListProvider k1HealingTipStringDOSCDEnglishProvider = { ARRAYSIZE(k1HealingTipStringDOSCDEnglish), k1HealingTipStringDOSCDEnglish };

static const char *const k1PoisonGoneStringDOSCDEnglish[2] = {
	"Amazing!",
	"The effects of the poison are gone!"
};

static const StringListProvider k1PoisonGoneStringDOSCDEnglishProvider = { ARRAYSIZE(k1PoisonGoneStringDOSCDEnglish), k1PoisonGoneStringDOSCDEnglish };

static const char *const k1ThePoisonStringsDOSCDEnglish[4] = {
	"The poison...",
	"I can't breathe...",
	"I don't feel so good...",
	"That snake must\rbe poisonous!"
};

static const StringListProvider k1ThePoisonStringsDOSCDEnglishProvider = { ARRAYSIZE(k1ThePoisonStringsDOSCDEnglish), k1ThePoisonStringsDOSCDEnglish };

static const char *const k1FluteStringsDOSCDEnglish[40] = {
	"Not very impressive sounding.",
	"That last note sure was high!",
	"\xBA",
	"\xBA",
	"",
	"\x01",
	"\x01\xB3",
	"\xB3",
	"\x06\x04\x08\x03\x06",
	"\x08\x01\x01",
	"\x02\x04",
	"\x05\x02",
	"\x08\x01\x01",
	"\x11",
	"5",
	"Y",
	"",
	"",
	"",
	"",
	"\x15",
	"9",
	"]",
	"",
	"",
	"",
	"",
	"\x07",
	")",
	"M",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"SHAPE_HORZ_REV",
	"SHAPE_VERT_REV"
};

static const StringListProvider k1FluteStringsDOSCDEnglishProvider = { ARRAYSIZE(k1FluteStringsDOSCDEnglish), k1FluteStringsDOSCDEnglish };

static const char *const k1WispJewelStringsDOSCDEnglish[2] = {
	"I'm not really feeling up to it right now.",
	"I probably should put down this first."
};

static const StringListProvider k1WispJewelStringsDOSCDEnglishProvider = { ARRAYSIZE(k1WispJewelStringsDOSCDEnglish), k1WispJewelStringsDOSCDEnglish };

static const char *const k1MagicJewelStringsDOSCDEnglish[1] = {
	"That felt strange."
};

static const StringListProvider k1MagicJewelStringsDOSCDEnglishProvider = { ARRAYSIZE(k1MagicJewelStringsDOSCDEnglish), k1MagicJewelStringsDOSCDEnglish };

static const char *const k1FlaskFullStringDOSCDEnglish[1] = {
	"This flask is already full."
};

static const StringListProvider k1FlaskFullStringDOSCDEnglishProvider = { ARRAYSIZE(k1FlaskFullStringDOSCDEnglish), k1FlaskFullStringDOSCDEnglish };

static const char *const k1FullFlaskStringDOSCDEnglish[4] = {
	"The flask is now filled\rwith fresh, sparkling water.",
	"The flask is now filled\rwith salt water.",
	"The flask is now filled\rwith mineral water.",
	"Magic water."
};

static const StringListProvider k1FullFlaskStringDOSCDEnglishProvider = { ARRAYSIZE(k1FullFlaskStringDOSCDEnglish), k1FullFlaskStringDOSCDEnglish };

static const char *const k1OutroHomeStringDOSCDEnglish[1] = {
	"Home"
};

static const StringListProvider k1OutroHomeStringDOSCDEnglishProvider = { ARRAYSIZE(k1OutroHomeStringDOSCDEnglish), k1OutroHomeStringDOSCDEnglish };

static const char *const k1VeryCleverStringDOSCDEnglish[1] = {
	"Very clever!  But your feeble efforts are futile."
};

static const StringListProvider k1VeryCleverStringDOSCDEnglishProvider = { ARRAYSIZE(k1VeryCleverStringDOSCDEnglish), k1VeryCleverStringDOSCDEnglish };

static const char *const k1GUIStringsDOSCDEnglish[81] = {
	"The Legend of Kyrandia",
	"Load a game",
	"Save this game",
	"Game controls",
	"Quit playing",
	"Resume game",
	"Game Controls",
	"Which game would you like to reload?",
	"Select a position to save to:",
	"[ EMPTY SLOT ]",
	"Cancel",
	"Enter a description of your saved game:",
	"Save",
	"Rest in peace, Brandon.",
	"Are you sure you want to quit playing?",
	"XXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXXXXXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXXXXXXXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXXXXXXXXXXX",
	"",
	"",
	"",
	"",
	"",
	"Main menu",
	"on",
	"off",
	"Yes",
	"No",
	"\xCD\x0E\x17""+""\xD5\x0E\x17""+""\xDA\x0E\x17""+""\xE1\x0E\x17""+""\xE6\x0E\x17""+""\xEE\x0E\x17""+""\xF8\x0E\x17""+""\x03\x0F\x17""+""\x10\x0F\x17""+""\x18\x0F\x17""+""\x1F\x0F\x17""+$""\x0F\x17""+Walk speed ",
	"Text speed ",
	"Music is ",
	"Sounds are ",
	"Voice / Text"
};

static const StringListProvider k1GUIStringsDOSCDEnglishProvider = { ARRAYSIZE(k1GUIStringsDOSCDEnglish), k1GUIStringsDOSCDEnglish };

static const char *const k1NewGameStringDOSCDEnglish[1] = {
	"[ START A NEW GAME ]"
};

static const StringListProvider k1NewGameStringDOSCDEnglishProvider = { ARRAYSIZE(k1NewGameStringDOSCDEnglish), k1NewGameStringDOSCDEnglish };

static const char *const k1ConfigStringsDOSCDEnglish[12] = {
	"slowest",
	"slow",
	"normal",
	"fast",
	"fastest",
	"Text only",
	"Voice only",
	"Voice & Text",
	"slowest",
	"normal",
	"fast",
	"clickable"
};

static const StringListProvider k1ConfigStringsDOSCDEnglishProvider = { ARRAYSIZE(k1ConfigStringsDOSCDEnglish), k1ConfigStringsDOSCDEnglish };

==> scummvm-2.9.1.tar.xz: scummvm-2.9.1/devtools/create_kyradat/resources/lok_dos_cd_english.h <==
static const char *const k1IntroStringsDOSCDEnglish[51] = {
	"This is a text test - 1",
	"This is a text test - 2",
	"Greetings, Kallak...",
	"...Powerful leader of the Royal Mystics!",
	"Did I frighten you?",
	"Malcolm!",
	"I heard yesterday of your escape.",
	"And have expected you before now.",
	"Why would I rush?",
	"I rule this land!",
	"Your puny curse restrains me naught.",
	"So, slay me now!",
	"I have little magic left.",
	"I mean to harm you, have no doubt...",
	"...Now you are stone...",
	"...Yet I leave your eyes.",
	"I shed no tears for Kyrandia...",
	"...But cannot deny you yours.",
	"Malcolm the Jester has broken free!",
	"He now controls the Kyragem...",
	"...source of all magic in Kyrandia!",
	"",
	"How dare you trip ME!",
	"But no, something special for you...",
	"A humorous hex!",
	"But I shall give fair warning.",
	"Don't jump on THAT tree!",
	"Don't climb up THAT tree little squirrel!",
	"Boo!",
	"Tis funnier that way...",
	"...Is it not?",
	"Ha ha ha...",
	"Aren't fingers wonderful?",
	"It's great to be alive!",
	"Brandon!",
	"Grandfather! We did it!",
	"No! YOU did it!",
	"Long live King Brandon!",
	"Long live the Royal Mystics!",
	"Now, let's go put Kyrandia back together!",
	"Good idea!",
	"As my first Royal Proclamation...",
	"I name sandals as the official footwear of Kyrandia!",
	"Well done, Brandon!",
	"The Land no longer weeps...",
	"And your friends have been restored!",
	"Dear Brynn...",
	"Malcolm has broken free!",
	"Soon he will come for me.",
	"Please help Brandon...",
	""
};

static const StringListProvider k1IntroStringsDOSCDEnglishProvider = { ARRAYSIZE(k1IntroStringsDOSCDEnglish), k1IntroStringsDOSCDEnglish };

static const char *const k1ItemNamesDOSCDEnglish[107] = {
	"Garnet",
	"Amethyst",
	"Aquamarine",
	"Diamond",
	"Emerald",
	"Pearl",
	"Ruby",
	"Peridot",
	"Sapphire",
	"Opal",
	"Topaz",
	"Onyx",
	"Sunstone",
	"Moonstone",
	"Rainbowstone",
	"Lodestone",
	"Rose",
	"Tulip",
	"Orchid",
	"Silver Rose",
	"Silver Statuette",
	"Silver Coin",
	"Gold Coin",
	"Gold Ring",
	"Royal Chalice",
	"Pinecone",
	"Acorn",
	"Walnut",
	"Everglowing Fireberries",
	"Fireberries",
	"Fireberries",
	"Fireberries",
	"Fireberries",
	"Fireberries",
	"Fish",
	"Fish Bone",
	"Mutton Leg",
	"Bone",
	"Apple",
	"Apple Core",
	"Blueberries",
	"Mushroom",
	"Note",
	"Marble",
	"Saw",
	"Ankh",
	"Feather",
	"Egg",
	"Leaf",
	"Shamrock",
	"Fallen Star",
	"Crystal Ball",
	"Teardrop",
	"Mirror",
	"Ice Shard",
	"Flute",
	"Hourglass",
	"Iron Key",
	"Jade Key",
	"Obsidion Key",
	"Red Potion",
	"Red Potion",
	"Blue Potion",
	"Blue Potion",
	"Yellow Potion",
	"Yellow Potion",
	"Green Potion",
	"Orange Potion",
	"Purple Potion",
	"Potion of Rainbows",
	"Fresh Water",
	"Fresh Water",
	"Salt Water",
	"Salt Water",
	"Mineral Water",
	"Mineral Water",
	"Magical Water",
	"Magical Water",
	"Empty Flask",
	"Empty Flask",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Scroll",
	"Parchment scrap",
	"Parchment scrap",
	"Parchment scrap",
	"Parchment scrap",
	"Parchment scrap",
	"Red Magestone",
	"Orange Magestone",
	"Yellow Magestone",
	"Green Magestone",
	"Blue-Green Magestone",
	"Blue Magestone",
	"Purple Magestone",
	"Heavy rock",
	"Royal Crown",
	"Royal Sceptre",
	"Gold key",
	"Unknown item"
};

static const StringListProvider k1ItemNamesDOSCDEnglishProvider = { ARRAYSIZE(k1ItemNamesDOSCDEnglish), k1ItemNamesDOSCDEnglish };

static const char *const k1TakenStringsDOSCDEnglish[2] = {
	" taken.",
	" taken."
};

static const StringListProvider k1TakenStringsDOSCDEnglishProvider = { ARRAYSIZE(k1TakenStringsDOSCDEnglish), k1TakenStringsDOSCDEnglish };

static const char *const k1PlacedStringsDOSCDEnglish[1] = {
	" placed."
};

static const StringListProvider k1PlacedStringsDOSCDEnglishProvider = { ARRAYSIZE(k1PlacedStringsDOSCDEnglish), k1PlacedStringsDOSCDEnglish };

static const char *const k1DroppedStringsDOSCDEnglish[1] = {
	" dropped."
};

static const StringListProvider k1DroppedStringsDOSCDEnglishProvider = { ARRAYSIZE(k1DroppedStringsDOSCDEnglish), k1DroppedStringsDOSCDEnglish };

static const char *const k1NoDropStringsDOSCDEnglish[2] = {
	"You can't drop any more items in this scene.",
	"You can't put that there."
};

static const StringListProvider k1NoDropStringsDOSCDEnglishProvider = { ARRAYSIZE(k1NoDropStringsDOSCDEnglish), k1NoDropStringsDOSCDEnglish };

static const char *const k1PutDownStringDOSCDEnglish[1] = {
	"Maybe I'd better put this down first."
};

static const StringListProvider k1PutDownStringDOSCDEnglishProvider = { ARRAYSIZE(k1PutDownStringDOSCDEnglish), k1PutDownStringDOSCDEnglish };

static const char *const k1WaitAmuletStringDOSCDEnglish[1] = {
	"I guess I'll have to wait for my Amulet to regain its power."
};

static const StringListProvider k1WaitAmuletStringDOSCDEnglishProvider = { ARRAYSIZE(k1WaitAmuletStringDOSCDEnglish), k1WaitAmuletStringDOSCDEnglish };

static const char *const k1BlackJewelStringDOSCDEnglish[1] = {
	"It's a jewel, but why is it black?"
};

static const StringListProvider k1BlackJewelStringDOSCDEnglishProvider = { ARRAYSIZE(k1BlackJewelStringDOSCDEnglish), k1BlackJewelStringDOSCDEnglish };

static const char *const k1HealingTipStringDOSCDEnglish[1] = {
	"Gee, this could come in handy if I get hurt."
};

static const StringListProvider k1HealingTipStringDOSCDEnglishProvider = { ARRAYSIZE(k1HealingTipStringDOSCDEnglish), k1HealingTipStringDOSCDEnglish };

static const char *const k1PoisonGoneStringDOSCDEnglish[2] = {
	"Amazing!",
	"The effects of the poison are gone!"
};

static const StringListProvider k1PoisonGoneStringDOSCDEnglishProvider = { ARRAYSIZE(k1PoisonGoneStringDOSCDEnglish), k1PoisonGoneStringDOSCDEnglish };

static const char *const k1ThePoisonStringsDOSCDEnglish[4] = {
	"The poison...",
	"I can't breathe...",
	"I don't feel so good...",
	"That snake must\rbe poisonous!"
};

static const StringListProvider k1ThePoisonStringsDOSCDEnglishProvider = { ARRAYSIZE(k1ThePoisonStringsDOSCDEnglish), k1ThePoisonStringsDOSCDEnglish };

static const char *const k1FluteStringsDOSCDEnglish[2] = {
	"Not very impressive sounding.",
	"That last note sure was high!"
};

static const StringListProvider k1FluteStringsDOSCDEnglishProvider = { ARRAYSIZE(k1FluteStringsDOSCDEnglish), k1FluteStringsDOSCDEnglish };

static const char *const k1WispJewelStringsDOSCDEnglish[2] = {
	"I'm not really feeling up to it right now.",
	"I probably should put down this first."
};

static const StringListProvider k1WispJewelStringsDOSCDEnglishProvider = { ARRAYSIZE(k1WispJewelStringsDOSCDEnglish), k1WispJewelStringsDOSCDEnglish };

static const char *const k1MagicJewelStringsDOSCDEnglish[1] = {
	"That felt strange."
};

static const StringListProvider k1MagicJewelStringsDOSCDEnglishProvider = { ARRAYSIZE(k1MagicJewelStringsDOSCDEnglish), k1MagicJewelStringsDOSCDEnglish };

static const char *const k1FlaskFullStringDOSCDEnglish[1] = {
	"This flask is already full."
};

static const StringListProvider k1FlaskFullStringDOSCDEnglishProvider = { ARRAYSIZE(k1FlaskFullStringDOSCDEnglish), k1FlaskFullStringDOSCDEnglish };

static const char *const k1FullFlaskStringDOSCDEnglish[4] = {
	"The flask is now filled\rwith fresh, sparkling water.",
	"The flask is now filled\rwith salt water.",
	"The flask is now filled\rwith mineral water.",
	"Magic water."
};

static const StringListProvider k1FullFlaskStringDOSCDEnglishProvider = { ARRAYSIZE(k1FullFlaskStringDOSCDEnglish), k1FullFlaskStringDOSCDEnglish };

static const char *const k1OutroHomeStringDOSCDEnglish[1] = {
	"Home"
};

static const StringListProvider k1OutroHomeStringDOSCDEnglishProvider = { ARRAYSIZE(k1OutroHomeStringDOSCDEnglish), k1OutroHomeStringDOSCDEnglish };

static const char *const k1VeryCleverStringDOSCDEnglish[1] = {
	"Very clever!  But your feeble efforts are futile."
};

static const StringListProvider k1VeryCleverStringDOSCDEnglishProvider = { ARRAYSIZE(k1VeryCleverStringDOSCDEnglish), k1VeryCleverStringDOSCDEnglish };

static const char *const k1GUIStringsDOSCDEnglish[81] = {
	"The Legend of Kyrandia",
	"Load a game",
	"Save this game",
	"Game controls",
	"Quit playing",
	"Resume game",
	"Game Controls",
	"Which game would you like to reload?",
	"Select a position to save to:",
	"[ EMPTY SLOT ]",
	"Cancel",
	"Enter a description of your saved game:",
	"Save",
	"Rest in peace, Brandon.",
	"Are you sure you want to quit playing?",
	"XXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXXXXXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXXXXXXXX",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"XXXXXXXXXXXX",
	"",
	"",
	"",
	"",
	"",
	"Main menu",
	"on",
	"off",
	"Yes",
	"No",
	"Walk speed ",
	"Text speed ",
	"Music is ",
	"Sounds are ",
	"Voice / Text"
};

static const StringListProvider k1GUIStringsDOSCDEnglishProvider = { ARRAYSIZE(k1GUIStringsDOSCDEnglish), k1GUIStringsDOSCDEnglish };

static const char *const k1NewGameStringDOSCDEnglish[1] = {
	"[ START A NEW GAME ]"
};

static const StringListProvider k1NewGameStringDOSCDEnglishProvider = { ARRAYSIZE(k1NewGameStringDOSCDEnglish), k1NewGameStringDOSCDEnglish };

static const char *const k1ConfigStringsDOSCDEnglish[12] = {
	"slowest",
	"slow",
	"normal",
	"fast",
	"fastest",
	"Text only",
	"Voice only",
	"Voice & Text",
	"slowest",
	"normal",
	"fast",
	"clickable"
};

static const StringListProvider k1ConfigStringsDOSCDEnglishProvider = { ARRAYSIZE(k1ConfigStringsDOSCDEnglish), k1ConfigStringsDOSCDEnglish };
